Documentation
¶
Index ¶
Constants ¶
const ( // ModelName is the name of the model ModelName = "count-sensor" // OverflowLabel is the label if the counts exceed what was specified by the user OverflowLabel = "Overflow" // DefaulMaxFrequency is how often the vision service will poll the camera for a new image DefaultPollFrequency = 1.0 )
Variables ¶
var ( // Model is the resource Model = resource.NewModel("viam", "vision-summary", ModelName) )
Functions ¶
This section is empty.
Types ¶
type Bin ¶
Bin stores the thresholds that turns counts into labels
func NewThresholds ¶
NewThresholds creates a list of thresholds for labeling counts
type Config ¶
type Config struct {
DetectorName string `json:"detector_name"`
CameraName string `json:"camera_name"`
ChosenLabels map[string]float64 `json:"chosen_labels"`
CountThresholds map[string]int `json:"count_thresholds"`
PollFrequency float64 `json:"poll_frequency_hz"`
}
Config contains names for necessary resources
Click to show internal directories.
Click to hide internal directories.